metarl: Meta Reinforcement Learning
=======================

### API

class `MAMLRL` implements MAML for RL tasks.


### Run Example

```
from metarl.maml import example as maml_example
maml_example()
```
